@@ -2,7 +2,7 @@
 
 __author__ = """Knut Rand"""
 __email__ = "knutdrand@gmail.com"
-__version__ = '0.2.12'
+__version__ = '0.2.16'
 
 import npstructures as nps
 
@@ -48,16 +48,20 @@ def set_backend(lib):
     from npstructures import RaggedArray
     from npstructures import RaggedShape, RaggedView
 
+    if not hasattr(lib, "object_"):
+        # hack for cupy
+        lib.object_ = None
+
     from .encodings import set_backend as set_encoding_backend
     set_encoding_backend(lib)
 
+    from .sequence import set_backend as set_sequence_backend
+    set_sequence_backend(lib)
+
     from bionumpy.cupy_compatible.parser import CupyFileReader
 
     from .io import file_buffers
     file_buffers.np = lib
-    file_buffers.RaggedArray = RaggedArray
-    file_buffers.RaggedShape = RaggedShape
-    file_buffers.RaggedView = RaggedView
 
     from .io import parser
     parser.np = lib
@@ -69,16 +73,11 @@ def set_backend(lib):
 
     from . import bnpdataclass
     bnpdataclass.np = lib
-    bnpdataclass.RaggedArray = RaggedArray
 
     from . import encoded_array
     encoded_array.np = lib
-    encoded_array.RaggedArray = RaggedArray
     encoded_array.get_NPSArray = lambda x: x
 
-    from .sequence import kmers
-    kmers.BitArray = BitArray
-
     from . import util
     util.np = lib
-    util.RaggedArray = RaggedArray
+
