@@ -82,9 +82,9 @@ buffers = {key: chunk_from_text(val) for key, val in buffer_texts.items()}
 
 data = {
     "bed": [
-        Bed6.single_entry("chr1", 1, 3, ".", 0, "-"),
-        Bed6.single_entry("chr1", 40, 60, ".", 1, "+"),
-        Bed6.single_entry("chr20",  400, 600, ".", 2, "+")],
+        Bed6.single_entry("chr1", 1, 3, ".", "0", "-"),
+        Bed6.single_entry("chr1", 40, 60, ".", "1", "+"),
+        Bed6.single_entry("chr20",  400, 600, ".", "2", "+")],
     "vcf2": [
         VCFEntry.single_entry("chr1",	88361, "rs4970378",	"A",	"G", ".", ".", "."),
         VCFEntry.single_entry("chr1",	887559, "rs3748595",	"A",	"CAA", ".", ".", "."),
@@ -109,8 +109,8 @@ data = {
         SAMEntry.single_entry("SRR1524970.144283", 16, "test_ref", 1705, 255, "25M",	"*", 0, 0, "TGCTGATGAAGCAGAACAACTTTAA", "]YG[^baaaa^W`ab]]````aaba"),
         SAMEntry.single_entry("SRR1524970.316478", 16, "test_ref", 1705, 255, "24M", "*", 0, 0, "TGCTGATGAAGCAGAACAACTTTA", 	"`\X_`aaaaaY]``b_aa_aaaaa")],
     "bed12": [
-        Bed12.single_entry("chr21", 10079666,  10120808,   "uc002yiv.1", 0, "-", 10081686, 10120608,  "0",     4,   [[528,91,101,215]], [[0,1930,39750,40927]]),
-        Bed12.single_entry("chr21", 10080031,  10081687,   "uc002yiw.1",  0,  "-",  10080031,  10080031,  "0",     2,   [[200,91]],    [[0,1565]])]
+        Bed12.single_entry("chr21", 10079666,  10120808,   "uc002yiv.1", "0", "-", 10081686, 10120608,  "0",     4,   [[528,91,101,215]], [[0,1930,39750,40927]]),
+        Bed12.single_entry("chr21", 10080031,  10081687,   "uc002yiw.1",  "0",  "-",  10080031,  10080031,  "0",     2,   [[200,91]],    [[0,1565]])]
 }
 
 
